/// <reference types="node" />
import { Sql } from 'postgres';
import { LargeObject } from './LargeObject';
import { ReadStream } from './ReadStream';
import { WriteStream } from './WriteStream';
declare enum MODE {
    WRITE = 131072,
    READ = 262144,
    READWRITE = 393216
}
/** This class lets you use the Large Object functionality of PostgreSQL.
 * All usage of Large Object should take place within a transaction block!
 * (BEGIN ... COMMIT)
 *
 * @example new LargeObjectManager(client)
 * @constructor
 * @exports postgres-large-object/lib/LargeObjectManager
 * @param {module:postgres/Sql} sql A postgres (https://www.npmjs.com/package/postgres) transaction
 *         object as given by `sql.begin(fn)`
 */
export declare class LargeObjectManager {
    static WRITE: MODE;
    static READ: MODE;
    static READWRITE: MODE;
    private _sql;
    constructor(sql: Sql<never>);
    /** Open an existing large object, based on its OID.
     * In mode READ, the data read from it will reflect the
     * contents of the large object at the time of the transaction
     * snapshot that was active when open was executed,
     * regardless of later writes by this or other transactions.
     * If opened using WRITE (or READWRITE), data read will reflect
     * all writes of other committed transactions as well as
     * writes of the current transaction.
     * @param {Number} oid
     * @param {Number} mode One of WRITE, READ, or READWRITE
     * @returns {Promise.<module:postgres-large-object/lib/LargeObject>}
     */
    openAsync: (oid: number, mode: MODE) => Promise<LargeObject>;
    /** @callback module:postgres-large-object/lib/LargeObjectManager~openCallback
     * @param {?Error} error If set, an error occurred.
     * @param {module:postgres-large-object/lib/LargeObject} result
     */
    /** Open an existing large object, based on its OID.
     * In mode READ, the data read from it will reflect the
     * contents of the large object at the time of the transaction
     * snapshot that was active when open was executed,
     * regardless of later writes by this or other transactions.
     * If opened using WRITE (or READWRITE), data read will reflect
     * all writes of other committed transactions as well as
     * writes of the current transaction.
     * @param {Number} oid
     * @param {Number} mode One of WRITE, READ, or READWRITE
     * @param {module:postgres-large-object/lib/LargeObjectManager~openCallback} callback
     */
    open: (arg1: number, arg2: MODE, callback: (err: NodeJS.ErrnoException | null, result: LargeObject) => void) => void;
    /** Creates a large object, returning its OID.
     * After which you can open() it.
     * @returns {Promise.<number>} oid
     */
    createAsync: () => Promise<number>;
    /** @callback module:postgres-large-object/lib/LargeObjectManager~createCallback
     * @param {?Error} error If set, an error occurred.
     * @param {Number} oid
     */
    /** Creates a large object, returning its OID.
     * After which you can open() it.
     * @param {module:postgres-large-object/lib/LargeObjectManager~createCallback} callback
     */
    create: (callback: (err: NodeJS.ErrnoException, result: number) => void) => void;
    /** Unlinks (deletes) a large object
     * @param {number} oid
     * @returns {Promise}
     */
    unlinkAsync: (oid: number) => Promise<void>;
    /** @callback module:postgres-large-object/lib/LargeObjectManager~unlinkCallback
     * @param {?Error} error If set, an error occurred.
     */
    /** Unlinks (deletes) a large object
     * @param {number} oid
     * @param {module:postgres-large-object/lib/LargeObjectManager~unlinkCallback} [callback]
     */
    unlink: (arg1: number, callback: (err: NodeJS.ErrnoException) => void) => void;
    /** Open a large object, return a stream and close the object when done streaming.
     * Only call this within a transaction block.
     * @param {Number} oid
     * @param {Number} [bufferSize=16384]
     * @returns {Promise.<Array>} The total size and a ReadStream
     *
     */
    openAndReadableStreamAsync: (oid: number, bufferSize?: number) => Promise<[number, ReadStream]>;
    /** @callback module:postgres-large-object/lib/LargeObjectManager~openAndReadableStreamCallback
     * @param {?Error} error If set, an error occurred.
     * @param {Number} size The total size of the large object
     * @param {module:postgres-large-object/lib/ReadStream} stream
     */
    /** Open a large object, return a stream and close the object when done streaming.
     * Only call this within a transaction block.
     * @param {Number} oid
     * @param {Number} [bufferSize=16384]
     * @param {module:postgres-large-object/lib/LargeObjectManager~openAndReadableStreamCallback} callback
     *
     */
    openAndReadableStream: {
        (oid: number, callback: (error?: Error, size?: number, stream?: ReadStream) => unknown): void;
        (oid: number, bufferSize: number, callback: (error?: Error, size?: number, stream?: ReadStream) => unknown): void;
    };
    /** Create and open a large object, return a stream and close the object when done streaming.
     * Only call this within a transaction block.
     * @param {Number} [bufferSize=16384]
     * @returns {promise.<Array>} The oid and a WriteStream
     */
    createAndWritableStreamAsync: (bufferSize?: number) => Promise<[number, WriteStream]>;
    /** @callback module:postgres-large-object/lib/LargeObjectManager~createAndWritableStreamCallback
     * @param {?Error} error If set, an error occurred.
     * @param {Number} oid
     * @param {module:postgres-large-object/lib/WriteStream} stream
     */
    /** Create and open a large object, return a stream and close the object when done streaming.
     * Only call this within a transaction block.
     * @param {Number} [bufferSize=16384]
     * @param {module:postgres-large-object/lib/LargeObjectManager~createAndWritableStreamCallback} [callback]
     */
    createAndWritableStream: {
        (callback: (error?: Error, oid?: number, stream?: WriteStream) => unknown): void;
        (bufferSize: number, callback: (error?: Error, oid?: number, stream?: WriteStream) => unknown): void;
    };
}
export {};
